Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
hadal/custom_logger.py | 9 | 0 | 0 | 100%
hadal/faiss_search.py | 33 | 8 | 0 | 76%
hadal/huggingface_automodel.py | 74 | 10 | 0 | 86%
hadal/parallel_sentence_mining/margin_based/margin_based.py | 43 | 4 | 0 | 91%
hadal/parallel_sentence_mining/margin_based/margin_based_tools.py | 47 | 7 | 0 | 85%
Total | 206 | 29 | 0 | 86%

No items found using the specified filter.